@@ -6,5 +6,6 @@ fixers.DestroyActiveButtons ()
 if VS.numActiveMissions()>1:
 	Base.Message('You are already doing a mission. Finish that instead.')
 else:
+	mission_lib.SetLastMission(0);
 	mission_lib.BriefLastMission(0,1)
-	VS.LoadMission('mission/internal1.mission')
+	VS.LoadMission('internal_mission_lib.mission')
